using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Design;
using System.IO;
using GrapeCity.ActiveReports.Design;
using GrapeCity.ActiveReports.Design.Resources;
using GrapeCity.ActiveReports;
using System.Xml;
namespace GrapeCity.ActiveReports.Samples.EndUserDesigner
{
    public partial class UnifiedDesignerForm : Form
    {
        ToolStripDropDownItem filemenu;
        public UnifiedDesignerForm()
        {
            InitializeComponent();
            //Populating the ToolBox,reportExplorer and Propertygrid
            this.reportdesigner.Toolbox = this.reporttoolbox;//Attaches the toolbox to the report designer
            this.reportExplorer.ReportDesigner = this.reportdesigner;//Attaches the report explorer to the report designer
            this.reportdesigner.PropertyGrid = this.reportpropertyGrid;//Attaches the Property Grid to the report designer
            //Populating the Menu
            ToolStrip toolstrip = this.reportdesigner.CreateToolStrips(new DesignerToolStrips[]{
               DesignerToolStrips.Menu,
            })[0];
            filemenu = (ToolStripDropDownItem)toolstrip.Items[0];
            this.CreateFileMenu(filemenu);
            this.AppendToolStrips(0, new ToolStrip[]
                    {
                            toolstrip
                     });
            this.AppendToolStrips(1, this.reportdesigner.CreateToolStrips(new DesignerToolStrips[]
                    {
                         DesignerToolStrips.Edit, 
                         DesignerToolStrips.Undo, 
                         DesignerToolStrips.Zoom
                     }));
            ToolStrip item = this.CreateReportToolbar();
            this.AppendToolStrips(1, new List<ToolStrip>
	             {
		               item
	             });
            this.AppendToolStrips(2, this.reportdesigner.CreateToolStrips(new DesignerToolStrips[]
                {
                   DesignerToolStrips.Format, 
                   DesignerToolStrips.Layout
                }));
            LoadTools(this.reporttoolbox);
        }
        private static void LoadTools(IToolboxService toolbox)
        {
            //Add Data Providers
            foreach (Type type in new Type[]
				{
					typeof (System.Data.DataSet),
					typeof (System.Data.DataView),
					typeof (System.Data.OleDb.OleDbConnection),
					typeof (System.Data.OleDb.OleDbDataAdapter),
					typeof (System.Data.Odbc.OdbcConnection),
					typeof (System.Data.Odbc.OdbcDataAdapter),
					typeof (System.Data.SqlClient.SqlConnection),
					typeof (System.Data.SqlClient.SqlDataAdapter)
				})
            {
                toolbox.AddToolboxItem(new ToolboxItem(type), "Data");
            }
        }
        //Adding DropDownItems to the ToolStripDropDownItem
        private void CreateFileMenu(ToolStripDropDownItem fileMenu)
        {
            fileMenu.DropDownItems.Clear();
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("New", Images.CmdNewReport, new EventHandler(this.OnNew), (Keys)131150));
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("Open", Images.CmdOpen, new EventHandler(this.OnOpen), (Keys)131151));
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("Export", null, new EventHandler(this.OnExport), (Keys)131152));
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("Save", Images.CmdSave, new EventHandler(this.OnSave), (Keys)131155));
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("Save As", Images.CmdSaveAs, new EventHandler(this.OnSaveAs)));
            fileMenu.DropDownItems.Add(new ToolStripSeparator());
            fileMenu.DropDownItems.Add(new ToolStripButton("Exit", null, new EventHandler(this.OnExit)));
        }
        private ToolStrip CreateReportToolbar()
        {
            return new ToolStrip(new ToolStripButton[]
            {
                UnifiedDesignerForm.CreateToolStripButton("New",Images.CmdNewReport,new EventHandler(this.OnNew),"New"),
                UnifiedDesignerForm.CreateToolStripButton("New",Images.CmdOpen,new EventHandler(this.OnOpen),"New"),
                UnifiedDesignerForm.CreateToolStripButton("Save",Images.CmdSave,new EventHandler(this.OnSave),"Save")
            });
        }
        //Getting the Designer to open a new Report on Menu Item "New" click
        private void OnNew(object sender, EventArgs e)
        {
            if (this.ConfirmSaveChanges())
            {
                this.reportdesigner.ExecuteAction(DesignerAction.NewReport);
            }
        }
        //Getting the Designer to open a Report on Menu Item "Open" click
        private void OnOpen(object sender, EventArgs e)
        {
            if (this.ConfirmSaveChanges())
            {
                this.reportdesigner.ExecuteAction(DesignerAction.FileOpen);
            }
        }
        private void OnExport(object sender, EventArgs e)
        {
            object _report = new object();
            try
            {
                _report = (GrapeCity.ActiveReports.SectionReport)this.reportdesigner.Report;
                ((GrapeCity.ActiveReports.SectionReport)_report).Run();
                SectionReportExportProperties _exportsection = new SectionReportExportProperties(((GrapeCity.ActiveReports.SectionReport)_report).Document);
                _exportsection.Show();
            }
            catch
            {
                try
                {
                    MemoryStream reporttobeexported = new MemoryStream();
                    XmlWriter reportwriter = XmlWriter.Create(reporttobeexported); 
                    this.reportdesigner.SaveReport(reportwriter);
                    reporttobeexported.Position = 0;
                    PageReportExportProperties _exportpage = new PageReportExportProperties(reporttobeexported);
                    _exportpage.Show();
                }
                catch(Exception ex)
                {
                    MessageBox.Show(ex.Message);
                }
            }
        }
        //Getting the Designer to Save the Report on Menu Item "Save" click
        private void OnSave(object sender, EventArgs e)
        {
            this.reportdesigner.ExecuteAction(DesignerAction.FileSave);
        }
        //Getting the Designer to Save the Report on Menu Item "Save As" click
        private void OnSaveAs(object sender, EventArgs e)
        {
            this.reportdesigner.ExecuteAction(DesignerAction.FileSaveAs);
        }
        private void OnExit(object sender, EventArgs e)
        {
            base.Close();
        }
        //Checking whether modifications have been made to the report loaded to the designer
        private bool ConfirmSaveChanges()
        {
            if (this.reportdesigner.IsDirty)
            {
                DialogResult dialogresult = MessageBox.Show("Report has been changed!!Do you wish to save it?", "", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Question);
                if (dialogresult == DialogResult.Cancel)
                {
                    return false;
                }
                else if (dialogresult == DialogResult.Yes)
                {
                    this.reportdesigner.ExecuteAction(DesignerAction.FileSave);
                }
            }
            return true;
        }
        private void AppendToolStrips(int row, IList<ToolStrip> toolStrips)
        {
            ToolStripPanel topToolStripPanel = this.toolStripContainer1.TopToolStripPanel;
            int num = toolStrips.Count;
            while (--num >= 0)
            {
                topToolStripPanel.Join(toolStrips[num], row);
            }
        }
        private static ToolStripButton CreateToolStripButton(string text, Image image, EventHandler handler, string toolTip)
        {
            return new ToolStripButton(text, image, handler)
            {
                DisplayStyle = ToolStripItemDisplayStyle.Image,
                ToolTipText = toolTip,
                DoubleClickEnabled = true
            };
        }
        private void UnifiedDesignerForm_Load(object sender, EventArgs e)
        {
        }

        private string _defaultConString = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=C:\\Users\\rajnish\\Documents\\ComponentOne Samples\\ActiveReports Developer 7\\Data\\NWIND.MDB;Persist Security Info=False";
        private void reportdesigner_DataSourceIconClick(object sender, DataSourceIconClickEventArgs e)
        {
            string reportQuery = string.Empty;

            // setting e.cancel to true willhide the default data source dialog to display.
            e.Cancel = true;

            SQLQueryBuilder.SQLQueryBuilder sqlQueryBuilder = new SQLQueryBuilder.SQLQueryBuilder();
            // assign the connection string
            sqlQueryBuilder.ConnectionString = this._defaultConString;

            // call showdialog and get the info based on dialog result
            if (sqlQueryBuilder.ShowDialog() == DialogResult.Cancel)
                return;


            reportQuery = sqlQueryBuilder.ReportQuery;


            GrapeCity.ActiveReports.Data.OleDBDataSource oledbDS = new GrapeCity.ActiveReports.Data.OleDBDataSource();
            oledbDS.ConnectionString = this._defaultConString;
            oledbDS.SQL = sqlQueryBuilder.ReportQuery;

            (this.reportdesigner.Report as SectionReport).DataSource = oledbDS;


        }
    }
}
